==> icon-0.0.4.tgz: package/es/helper.js <==
import { createElement as v } from "react";
import { ArValidImageMimeTypes as p, ArIconSourceTypes as f, ArThemes as S } from "@armco/types";
const u = new DOMParser(), m = u.parseFromString(
  `<svg stroke="currentColor" fill="currentColor" stroke-width="0" viewBox="0 0 24 24" height="1em" width="1em" xmlns="http://www.w3.org/2000/svg">
      <rect width="20" height="20" x="2" y="2" fill="none" stroke="#000" stroke-width="2"rx="2"></rect>
    </svg>`,
  p.SVG
).querySelector("svg"), w = /^[a-zA-Z]{2,3}[./][a-zA-Z0-9]+$/, y = (t) => typeof t == "object" ? f.raw : t.startsWith("data:image/svg+xml;base64,") ? f.b64 : t.startsWith("<svg") ? f.svgString : t.startsWith("http://") || t.startsWith("https://") ? f.URL : w.test(t) ? f.identifier : f.b64, k = (t) => {
  try {
    const n = u.parseFromString(t, p.SVG).querySelector("svg");
    return console.warn("Parsed item isn't an svg"), n === null ? m : n;
  } catch (o) {
    return console.warn("Error parsing SVG string:", o), m;
  }
}, F = (t) => {
  try {
    const o = atob(t);
    return k(o);
  } catch (o) {
    return console.error("Error decoding base64 SVG string:", o), m;
  }
}, V = (t) => {
  const o = (n) => {
    const e = Array.from(n.children).map(o), c = Array.from(n.attributes).reduce((i, r) => (i[r.name] = r.value, i), {});
    return v(n.tagName, c, ...e);
  };
  return o(t);
}, C = (t, o) => {
  const { attributes: n, theme: e } = t, { colors: c } = n || {}, {
    strokeColor: i,
    toggleStrokeColor: r,
    hoverStrokeColor: s,
    darkStrokeColor: a,
    darkToggleStrokeColor: l,
    darkHoverStrokeColor: g
  } = c || {}, { hovered: h, toggled: d } = o;
  return e === S.DARK1 ? h && g ? g : d && l ? l : a : h && s ? s : d && r ? r : i;
}, A = (t, o) => {
  const { attributes: n, theme: e } = t, { colors: c } = n || {}, {
    fillColor: i,
    toggleFillColor: r,
    hoverFillColor: s,
    darkFillColor: a,
    darkToggleFillColor: l,
    darkHoverFillColor: g
  } = c || {}, { hovered: h, toggled: d } = o;
  return e === S.DARK1 ? h && g ? g : d && l ? l : a : h && s ? s : d && r ? r : i;
}, E = (t, o, n) => {
  if (!(t instanceof SVGSVGElement))
    return;
  const { attributes: e, hoverShadow: c } = o, { strokeWidth: i, styles: r } = e || {}, s = ((e == null ? void 0 : e.classes) || "") + (c ? " hover-shadow p-1" : ""), a = A(o, n), l = C(o, n), g = (e == null ? void 0 : e.height) || (typeof (r == null ? void 0 : r.height) == "number" ? typeof (r == null ? void 0 : r.height) + "px" : typeof (r == null ? void 0 : r.height)) || (e == null ? void 0 : e.size) || "1rem", h = (e == null ? void 0 : e.width) || (typeof (r == null ? void 0 : r.width) == "number" ? typeof (r == null ? void 0 : r.width) + "px" : typeof (r == null ? void 0 : r.width)) || (e == null ? void 0 : e.size) || "1rem";
  a && t.setAttribute("fill", a), l && t.setAttribute("stroke", l), i && t.setAttribute("stroke-width", i), t.setAttribute("width", h), t.setAttribute("height", g), t.setAttribute("class", `ar-Icon${s ? " " + s : ""}`), r && Object.assign(t.style, r);
};
export {
  E as applyStyles,
  V as createElementFromSvg,
  A as getFillColor,
  C as getStrokeColor,
  y as inferIconType,
  F as parseSvgB64String,
  k as parseSvgString,
  m as placeholder
};

==> icon-0.0.6.tgz: package/es/helper.js <==
import { createElement as v } from "react";
import { ArValidImageMimeTypes as p, ArIconSourceTypes as f, ArThemes as S } from "@armco/types";
const u = new DOMParser(), m = u.parseFromString(
  `<svg stroke="currentColor" fill="currentColor" stroke-width="0" viewBox="0 0 24 24" height="1em" width="1em" xmlns="http://www.w3.org/2000/svg">
      <rect width="20" height="20" x="2" y="2" fill="none" stroke="#000" stroke-width="2"rx="2"></rect>
    </svg>`,
  p.SVG
).querySelector("svg"), w = /^[a-zA-Z]{2,3}[.\/][a-zA-Z0-9]+$/, y = (t) => typeof t == "object" ? f.raw : t.startsWith("data:image/svg+xml;base64,") ? f.b64 : t.startsWith("<svg") ? f.svgString : t.startsWith("http://") || t.startsWith("https://") ? f.URL : w.test(t) ? f.identifier : f.b64, k = (t) => {
  try {
    const n = u.parseFromString(t, p.SVG).querySelector("svg");
    return console.warn("Parsed item isn't an svg"), n === null ? m : n;
  } catch (o) {
    return console.warn("Error parsing SVG string:", o), m;
  }
}, F = (t) => {
  try {
    const o = atob(t);
    return k(o);
  } catch (o) {
    return console.error("Error decoding base64 SVG string:", o), m;
  }
}, V = (t) => {
  const o = (n) => {
    const e = Array.from(n.children).map(o), c = Array.from(n.attributes).reduce((i, r) => (i[r.name] = r.value, i), {});
    return v(n.tagName, c, ...e);
  };
  return o(t);
}, C = (t, o) => {
  const { attributes: n, theme: e } = t, { colors: c } = n || {}, {
    strokeColor: i,
    toggleStrokeColor: r,
    hoverStrokeColor: s,
    darkStrokeColor: a,
    darkToggleStrokeColor: l,
    darkHoverStrokeColor: g
  } = c || {}, { hovered: h, toggled: d } = o;
  return e === S.DARK1 ? h && g ? g : d && l ? l : a : h && s ? s : d && r ? r : i;
}, A = (t, o) => {
  const { attributes: n, theme: e } = t, { colors: c } = n || {}, {
    fillColor: i,
    toggleFillColor: r,
    hoverFillColor: s,
    darkFillColor: a,
    darkToggleFillColor: l,
    darkHoverFillColor: g
  } = c || {}, { hovered: h, toggled: d } = o;
  return e === S.DARK1 ? h && g ? g : d && l ? l : a : h && s ? s : d && r ? r : i;
}, E = (t, o, n) => {
  if (!(t instanceof SVGSVGElement))
    return;
  const { attributes: e, hoverShadow: c } = o, { strokeWidth: i, styles: r } = e || {}, s = ((e == null ? void 0 : e.classes) || "") + (c ? " hover-shadow p-1" : ""), a = A(o, n), l = C(o, n), g = (e == null ? void 0 : e.height) || (typeof (r == null ? void 0 : r.height) == "number" ? typeof (r == null ? void 0 : r.height) + "px" : typeof (r == null ? void 0 : r.height)) || (e == null ? void 0 : e.size) || "1rem", h = (e == null ? void 0 : e.width) || (typeof (r == null ? void 0 : r.width) == "number" ? typeof (r == null ? void 0 : r.width) + "px" : typeof (r == null ? void 0 : r.width)) || (e == null ? void 0 : e.size) || "1rem";
  a && t.setAttribute("fill", a), l && t.setAttribute("stroke", l), i && t.setAttribute("stroke-width", i), t.setAttribute("width", h), t.setAttribute("height", g), t.setAttribute("class", `ar-Icon${s ? " " + s : ""}`), r && Object.assign(t.style, r);
};
export {
  E as applyStyles,
  V as createElementFromSvg,
  A as getFillColor,
  C as getStrokeColor,
  y as inferIconType,
  F as parseSvgB64String,
  k as parseSvgString,
  m as placeholder
};
